(function() {
  "use strict";

  /**
   * Apply .scrolled class to the body as the page is scrolled down
   */
  function toggleScrolled() {
    const selectBody = document.querySelector('body');
    const selectHeader = document.querySelector('#header');
    if (!selectHeader.classList.contains('scroll-up-sticky') && !selectHeader.classList.contains('sticky-top') && !selectHeader.classList.contains('fixed-top')) return;
    window.scrollY > 100 ? selectBody.classList.add('scrolled') : selectBody.classList.remove('scrolled');
  }

  document.addEventListener('scroll', toggleScrolled);
  window.addEventListener('load', toggleScrolled);


	let lastScrollTop = 0;
	const header = document.getElementById('header');

	window.addEventListener('scroll', function() {
		const scrollTop = window.pageYOffset || document.documentElement.scrollTop;

		if (scrollTop > lastScrollTop) {
			// Scrolling down - hide the header
			header.classList.add('hidden-head');
		} else {
			// Scrolling up - show the header
			header.classList.remove('hidden-head');
		}

		lastScrollTop = scrollTop <= 0 ? 0 : scrollTop; // For mobile or negative scrolling
	});

  /**
   * Mobile nav toggle
   */
  const mobileNavToggleBtn = document.querySelector('.mobile-nav-toggle');

  function mobileNavToogle() {
    document.querySelector('body').classList.toggle('mobile-nav-active');
    mobileNavToggleBtn.classList.toggle('bi-list');
    mobileNavToggleBtn.classList.toggle('bi-x');
  }
  mobileNavToggleBtn.addEventListener('click', mobileNavToogle);

  /**
   * Hide mobile nav on same-page/hash links
   */
  document.querySelectorAll('#navmenu a').forEach(navmenu => {
    navmenu.addEventListener('click', () => {
      if (document.querySelector('.mobile-nav-active')) {
        mobileNavToogle();
      }
    });

  });

  /**
   * Toggle mobile nav dropdowns
   */
  document.querySelectorAll('.navmenu .toggle-dropdown').forEach(navmenu => {
    navmenu.addEventListener('click', function(e) {
      e.preventDefault();
      this.parentNode.classList.toggle('active');
      this.parentNode.nextElementSibling.classList.toggle('dropdown-active');
      e.stopImmediatePropagation();
    });
  });

  /**
   * Preloader
   */
  const preloader = document.querySelector('#preloader');
  if (preloader) {
    window.addEventListener('load', () => {
      preloader.remove();
    });
  }

  /**
   * Scroll top button
   */
  let scrollTop = document.querySelector('.scroll-top');

  function toggleScrollTop() {
    if (scrollTop) {
      window.scrollY > 100 ? scrollTop.classList.add('active') : scrollTop.classList.remove('active');
    }
  }
  scrollTop.addEventListener('click', (e) => {
    e.preventDefault();
    window.scrollTo({
      top: 0,
      behavior: 'smooth'
    });
  });

  window.addEventListener('load', toggleScrollTop);
  document.addEventListener('scroll', toggleScrollTop);

  /**
   * Animation on scroll function and init
   */
  function aosInit() {
    AOS.init({
      duration: 600,
      easing: 'ease-in-out',
      once: true,
      mirror: false,
			disable: 'mobile'
    });
  }
  window.addEventListener('load', aosInit);

  /**
   * Init swiper sliders
   */
  function initSwiper() {
    document.querySelectorAll(".init-swiper").forEach(function(swiperElement) {
      let config = JSON.parse(
        swiperElement.querySelector(".swiper-config").innerHTML.trim()
      );

      if (swiperElement.classList.contains("swiper-tab")) {
        initSwiperWithCustomPagination(swiperElement, config);
      } else {
        new Swiper(swiperElement, config);
      }
    });
  }

  window.addEventListener("load", initSwiper);

  /**
   * Swiper Js
   */
	
	var swiper2 = new Swiper(".testi-swipe", {
		spaceBetween: 10,
		loop: true,
		autoplay: {
			delay: 2000,
		},
		navigation: {
			nextEl: '.swiper-button-next3',
			prevEl: '.swiper-button-prev3'
		},
		breakpoints: {
			640: {
				slidesPerView: 1,
			},
			768: {
				slidesPerView: 3,
			},
			1024: {
				slidesPerView: 4,
			}
		}
	});

  /**
   * Swiper Js
   */
	var swiper = new Swiper(".mySwiper", {
		centeredSlides: true,
		loop: true,
		autoplay: {
			delay: 0,
			disableOnInteraction: false,
		},
		speed: 4000,
		pagination: {
			el: ".swiper-pagination",
			clickable: true,
		},
		navigation: {
			nextEl: ".swiper-button-next",
			prevEl: ".swiper-button-prev",
		},
		breakpoints: {
			380: {
				slidesPerView: 2,
				spaceBetween: 10,
			},
			640: {
				slidesPerView: 2,
				spaceBetween: 10,
			},
			768: {
				slidesPerView: 3,
				spaceBetween: 10,
			},
			1024: {
				slidesPerView: 4,
				spaceBetween: 20,
			}
		}
	});
	$(".swiper-slide").hover(
		function () {
			swiper.autoplay.stop();
		},
		function () {
			swiper.autoplay.start();
		}
	);
	
	
  /**
   * lightGallery
   */

	lightGallery(document.getElementById('lsaGallery'), {
    thumbnail: true,
		autoplayFirstVideo: false,
		pager: false,
		galleryId: "nature",
		plugins: [lgZoom, lgThumbnail, lgVideo],
		mobileSettings: {
			controls: false,
			showCloseIcon: false,
			rotate: false
		},
    videojs: true,
    videojsOptions: {
			autoplay: true,
			muted: false,
    },
	});

	// Select all elements with the class 'filter-video'
	const filterVideos = document.querySelectorAll('.filter-video');

	// Iterate over each element and append a new div with the class 'video-icon' and its contents
	filterVideos.forEach(element => {
			const videoIcon = document.createElement('div');
			videoIcon.className = 'video-icon';
			// Create the <i> element and set its class
			const icon = document.createElement('i');
			icon.className = 'bx bxl-youtube';
			// Append the <i> element to the <div>
			videoIcon.appendChild(icon);
			// Append the <div> to the element with the class 'filter-video'
			element.appendChild(videoIcon);
	});

  /**
   * Initiate Pure Counter
   */
  new PureCounter();

  /**
   * Initiate glightbox
   */
  const glightbox = GLightbox({
    selector: '.glightbox'
  });

  /**
   * Frequently Asked Questions Toggle
   */
  document.querySelectorAll('.faq-item h3, .faq-item .faq-toggle').forEach((faqItem) => {
    faqItem.addEventListener('click', () => {
      faqItem.parentNode.classList.toggle('faq-active');
    });
  });

  /**
   * Animate the skills items on reveal
   */
  let skillsAnimation = document.querySelectorAll('.skills-animation');
  skillsAnimation.forEach((item) => {
    new Waypoint({
      element: item,
      offset: '80%',
      handler: function(direction) {
        let progress = item.querySelectorAll('.progress .progress-bar');
        progress.forEach(el => {
          el.style.width = el.getAttribute('aria-valuenow') + '%';
        });
      }
    });
  });

  /**
   * Correct scrolling position upon page load for URLs containing hash links.
   */
  window.addEventListener('load', function(e) {
    if (window.location.hash) {
      if (document.querySelector(window.location.hash)) {
        setTimeout(() => {
          let section = document.querySelector(window.location.hash);
          let scrollMarginTop = getComputedStyle(section).scrollMarginTop;
          window.scrollTo({
            top: section.offsetTop - parseInt(scrollMarginTop),
            behavior: 'smooth'
          });
        }, 100);
      }
    }
  });

  /**
   * Navmenu Scrollspy
   */
  let navmenulinks = document.querySelectorAll('.navmenu a');

  function navmenuScrollspy() {
    navmenulinks.forEach(navmenulink => {
      if (!navmenulink.hash) return;
      let section = document.querySelector(navmenulink.hash);
      if (!section) return;
      let position = window.scrollY + 200;
      if (position >= section.offsetTop && position <= (section.offsetTop + section.offsetHeight)) {
        document.querySelectorAll('.navmenu a.active').forEach(link => link.classList.remove('active'));
        navmenulink.classList.add('active');
      } else {
        navmenulink.classList.remove('active');
      }
    })
  }
  window.addEventListener('load', navmenuScrollspy);
  document.addEventListener('scroll', navmenuScrollspy);

	var hoverMouse = function ($el) {
    $el.each(function () {
      var $self = $(this);
      var hover = false;
      var offsetHoverMax = $self.attr("offset-hover-max") || 0.7;
      var offsetHoverMin = $self.attr("offset-hover-min") || 0.5;

      var attachEventsListener = function () {
        $(window).on("mousemove", function (e) {
          var hoverArea = hover ? offsetHoverMax : offsetHoverMin;

          // cursor
          var cursor = {
            x: e.clientX,
            y: e.pageY
          };

          // size
          var width = $self.outerWidth();
          var height = $self.outerHeight();

          // position
          var offset = $self.offset();
          var elPos = {
            x: offset.left + width / 2,
            y: offset.top + height / 2
          };

          // comparison
          var x = cursor.x - elPos.x;
          var y = cursor.y - elPos.y;

          // distance
          var dist = Math.sqrt(x * x + y * y);

          // mutex hover
          var mutHover = false;

          // animation
          if (dist < width * hoverArea) {
            mutHover = true;
            if (!hover) {
              hover = true;
            }
            onHover(x, y);
          }

          // reset
          if (!mutHover && hover) {
            onLeave();
            hover = false;
          }
        });
      };

      var onHover = function (x, y) {
        TweenMax.to($self, 0.4, {
          x: x * 0.8,
          y: y * 0.8,
          rotation: x * 0.05,
          ease: Power2.easeOut
        });
      };

      var onLeave = function () {
        TweenMax.to($self, 0.7, {
          x: 0,
          y: 0,
          scale: 1,
          rotation: 0,
          ease: Elastic.easeOut.config(1.2, 0.4)
        });
      };

      attachEventsListener();
    });
  };

  // Apply hoverMouse functionality to the images
  hoverMouse($(".mag-sec"));

})();